==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=gl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'A afiliación fallou: o ficheiro de «backend» indicado é indescifrable ou non trae ningún artigo.',
	'avis_echec_syndication_02' => 'A afiliación fallou: foi imposible acceder ao ficheiro «backend» deste web.',
	'avis_site_introuvable' => 'Non se pode atopar o web',
	'avis_site_syndique_probleme' => 'Atención: a afiliación deste web atopou un problema; o sistema quedou temporalmente interrompido. Verifique o enderezo do ficheiro de afiliación deste web (<b>@url_syndic@</b>), e tente unha nova recuperación da información.',
	'avis_sites_probleme_syndication' => 'Estes webs atoparon un problema de afiliación',
	'avis_sites_syndiques_probleme' => 'Estes webs afiliados devolveron un problema',

	// B
	'bouton_radio_modere_posteriori' => 'moderación a posteriori', # MODIF
	'bouton_radio_modere_priori' => 'moderación a priori', # MODIF
	'bouton_radio_non_syndication' => 'Sen afiliación',
	'bouton_radio_syndication' => 'Afiliación:',

	// E
	'entree_adresse_fichier_syndication' => 'Enderezo do ficheiro de afiliación :',
	'entree_adresse_site' => '<b>Enderezo do web</b> [Obrigatorio]',
	'entree_description_site' => 'Descrición do web',

	// F
	'form_prop_nom_site' => 'Nome do web',

	// I
	'icone_modifier_site' => 'Modificar este web',
	'icone_referencer_nouveau_site' => 'Referencia dun novo web',
	'icone_voir_sites_references' => 'Ver os webs referidos',
	'info_a_valider' => '[a validar]',
	'info_bloquer' => 'bloquear',
	'info_bloquer_lien' => 'Bloquear esta ligazón',
	'info_derniere_syndication' => 'A última afiliación deste web fíxose o',
	'info_liens_syndiques_1' => 'ligazón afiliada',
	'info_liens_syndiques_2' => 'están agardando pola validación.',
	'info_nom_site_2' => '<b>Nome do web</b>[Obrigatorio]',
	'info_panne_site_syndique' => 'Web afiliado caído',
	'info_probleme_grave' => 'problema de',
	'info_question_proposer_site' => 'Quen pode propor os webs referidos?',
	'info_retablir_lien' => 'reestablecer esta ligazón',
	'info_site_attente' => 'Sitio web agardando pola validación',
	'info_site_propose' => 'Web proposto o:',
	'info_site_reference' => 'Web referido en liña',
	'info_site_refuse' => 'Web rexeitado',
	'info_site_syndique' => 'Este web está afiliado...', # MODIF
	'info_site_valider' => 'Webs por validar',
	'info_sites_referencer' => 'Referenciar un web',
	'info_sites_refuses' => 'Os webs rexeitados',
	'info_statut_site_1' => 'Este web foi:',
	'info_statut_site_2' => 'Publicado',
	'info_statut_site_3' => 'Proposto',
	'info_statut_site_4' => 'No lixo', # MODIF
	'info_syndication' => 'sindicación :',
	'info_syndication_articles' => 'artigo(s)',
	'item_bloquer_liens_syndiques' => 'Bloquear as ligazóns afiliadas para validación',
	'item_gerer_annuaire_site_web' => 'Xestionar unha guía de webs',
	'item_non_bloquer_liens_syndiques' => 'Non bloquear as ligazóns afiliadas',
	'item_non_gerer_annuaire_site_web' => 'Desactivar o directorio/guía de webs',
	'item_non_utiliser_syndication' => 'Non usar a afiliación automática',
	'item_utiliser_syndication' => 'Empregar a afiliación automática',

	// L
	'lien_mise_a_jour_syndication' => 'Poñer ao día agora',
	'lien_nouvelle_recuperation' => 'Tentar unha nova recuperación dos datos',

	// S
	'syndic_choix_moderation' => 'Que facer das vindeiras ligazóns que proveñan deste web ?',
	'syndic_choix_oublier' => 'Que facer das ligazóns que xa non figuran no ficheiro de subscrición ?',
	'syndic_choix_resume' => 'Algúns webs difunden o texto completo dos artigos. No caso de que isto estea dispoñíbel desexa sindicalo :',
	'syndic_lien_obsolete' => 'ligazón obsoleta',
	'syndic_option_miroir' => 'bloquealas automaticamente',
	'syndic_option_oubli' => 'borralas (tras @mois@ mois)',
	'syndic_option_resume_non' => 'o contido completo dos artigos (en formato HTML)',
	'syndic_option_resume_oui' => 'un simple resumo (en formato de texto)',
	'syndic_options' => 'Opcións da subscrición :',

	// T
	'texte_liens_sites_syndiques' => 'As ligazóns procedentes dos webs afiliados
  poden ser bloquedas a priori; o axuste aquí embaixo indica a configuración
  por defecto dos web afiliados logo da súa creación.
  De todos os xeitos despois é posible desbloquear cada ligazón individualmente,
  ou escoller, web por web, o bloqueo das ligazóns futuras de tal ou cal web.', # MODIF
	'texte_messages_publics' => 'Mensaxes públicas do artigo:',
	'texte_non_fonction_referencement' => 'Pode preferir non usar esta función automática, e indicar á man os elementos concernintes a este web...', # MODIF
	'texte_referencement_automatique' => '<b>Referencia automatizada dun web</b><br />Pode referir rapidamente un  web ao indicar aquí embaixo o enderezo URL desexado, ou o enderezo do seu ficheiro de afiliación. SPIP recuperará automaticamente as informacións concernintes a este lugar (título, descrición...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Comprobe os datos fornecidos por <tt>@url@</tt> antes de rexistralos.',
	'texte_syndication' => 'Pódese recuperar automaticamente, e sempre que o sitio web o permita, 
  a súa lista de novidades. Para isto, ten que activar a afiliación.
  <blockquote><i>Algúns aloxadores desactivan esta funcionalidade;
  nese caso, non poderá empregar a afiliación de contido
  dende o seu web.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Artigos afiliados extraídos deste web',
	'titre_dernier_article_syndique' => 'Últimos artigos afiliados',
	'titre_page_sites_tous' => 'Os webs referidos',
	'titre_referencement_sites' => 'Referencia de webs e afiliación',
	'titre_site_numero' => 'WEB NÚMERO:',
	'titre_sites_proposes' => 'Os webs propostos',
	'titre_sites_references_rubrique' => 'Os webs referenciados neste tema',
	'titre_sites_syndiques' => 'Os webs afiliados',
	'titre_sites_tous' => 'Os webs referidos',
	'titre_syndication' => 'Subscrición de webs'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=gl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'A afiliación fallou: o ficheiro de «backend» indicado é indescifrable ou non trae ningún artigo.',
	'avis_echec_syndication_02' => 'A afiliación fallou: foi imposible acceder ao ficheiro «backend» deste web.',
	'avis_site_introuvable' => 'Non se pode atopar o web',
	'avis_site_syndique_probleme' => 'Atención: a afiliación deste web atopou un problema; o sistema quedou temporalmente interrompido. Verifique o enderezo do ficheiro de afiliación deste web (<b>@url_syndic@</b>), e tente unha nova recuperación da información.',
	'avis_sites_probleme_syndication' => 'Estes webs atoparon un problema de afiliación',
	'avis_sites_syndiques_probleme' => 'Estes webs afiliados devolveron un problema',

	// B
	'bouton_radio_modere_posteriori' => 'moderación a posteriori', # MODIF
	'bouton_radio_modere_priori' => 'moderación a priori', # MODIF
	'bouton_radio_non_syndication' => 'Sen afiliación',
	'bouton_radio_syndication' => 'Afiliación:',

	// E
	'entree_adresse_fichier_syndication' => 'Enderezo do ficheiro de afiliación :',
	'entree_adresse_site' => '<b>Enderezo do web</b> [Obrigatorio]',
	'entree_description_site' => 'Descrición do web',

	// F
	'form_prop_nom_site' => 'Nome do web',

	// I
	'icone_modifier_site' => 'Modificar este web',
	'icone_referencer_nouveau_site' => 'Referencia dun novo web',
	'icone_voir_sites_references' => 'Ver os webs referidos',
	'info_1_article_syndique' => '1 artigo sindicado',
	'info_1_site' => '1 web',
	'info_a_valider' => '[a validar]',
	'info_aucun_article_syndique' => 'Ningún artigo sindicado',
	'info_aucun_site' => 'Ningún sitio',
	'info_bloquer' => 'bloquear',
	'info_bloquer_lien' => 'Bloquear esta ligazón',
	'info_derniere_syndication' => 'A última afiliación deste web fíxose o',
	'info_liens_syndiques_1' => 'ligazón afiliada',
	'info_liens_syndiques_2' => 'están agardando pola validación.',
	'info_nb_articles_syndiques' => '@nb@ artigos sindicados',
	'info_nb_sites' => '@nb@ sitios',
	'info_nom_site_2' => '<b>Nome do web</b>[Obrigatorio]',
	'info_panne_site_syndique' => 'Web afiliado caído',
	'info_probleme_grave' => 'problema de',
	'info_question_proposer_site' => 'Quen pode propor os webs referidos?',
	'info_retablir_lien' => 'reestablecer esta ligazón',
	'info_site_attente' => 'Sitio web agardando pola validación',
	'info_site_propose' => 'Web proposto o:',
	'info_site_reference' => 'Web referido en liña',
	'info_site_refuse' => 'Web rexeitado',
	'info_site_syndique' => 'Este web está afiliado...', # MODIF
	'info_site_valider' => 'Webs por validar',
	'info_sites_referencer' => 'Referenciar un web',
	'info_sites_refuses' => 'Os webs rexeitados',
	'info_statut_site_1' => 'Este web foi:',
	'info_statut_site_2' => 'Publicado',
	'info_statut_site_3' => 'Proposto',
	'info_statut_site_4' => 'No lixo', # MODIF
	'info_syndication' => 'sindicación :',
	'info_syndication_articles' => 'artigo(s)',
	'item_bloquer_liens_syndiques' => 'Bloquear as ligazóns afiliadas para validación',
	'item_gerer_annuaire_site_web' => 'Xestionar unha guía de webs',
	'item_non_bloquer_liens_syndiques' => 'Non bloquear as ligazóns afiliadas',
	'item_non_gerer_annuaire_site_web' => 'Desactivar o directorio/guía de webs',
	'item_non_utiliser_syndication' => 'Non usar a afiliación automática',
	'item_utiliser_syndication' => 'Empregar a afiliación automática',

	// L
	'lien_mise_a_jour_syndication' => 'Poñer ao día agora',
	'lien_nouvelle_recuperation' => 'Tentar unha nova recuperación dos datos',

	// S
	'syndic_choix_moderation' => 'Que facer das vindeiras ligazóns que proveñan deste web ?',
	'syndic_choix_oublier' => 'Que facer das ligazóns que xa non figuran no ficheiro de subscrición ?',
	'syndic_choix_resume' => 'Algúns webs difunden o texto completo dos artigos. No caso de que isto estea dispoñíbel desexa sindicalo :',
	'syndic_lien_obsolete' => 'ligazón obsoleta',
	'syndic_option_miroir' => 'bloquealas automaticamente',
	'syndic_option_oubli' => 'borralas (tras @mois@ mois)',
	'syndic_option_resume_non' => 'o contido completo dos artigos (en formato HTML)',
	'syndic_option_resume_oui' => 'un simple resumo (en formato de texto)',
	'syndic_options' => 'Opcións da subscrición :',

	// T
	'texte_liens_sites_syndiques' => 'As ligazóns procedentes dos webs afiliados
  poden ser bloquedas a priori; o axuste aquí embaixo indica a configuración
  por defecto dos web afiliados logo da súa creación.
  De todos os xeitos despois é posible desbloquear cada ligazón individualmente,
  ou escoller, web por web, o bloqueo das ligazóns futuras de tal ou cal web.', # MODIF
	'texte_messages_publics' => 'Mensaxes públicas do artigo:',
	'texte_non_fonction_referencement' => 'Pode preferir non usar esta función automática, e indicar á man os elementos concernintes a este web...', # MODIF
	'texte_referencement_automatique' => '<b>Referencia automatizada dun web</b><br />Pode referir rapidamente un  web ao indicar aquí embaixo o enderezo URL desexado, ou o enderezo do seu ficheiro de afiliación. SPIP recuperará automaticamente as informacións concernintes a este lugar (título, descrición...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Comprobe os datos fornecidos por <tt>@url@</tt> antes de rexistralos.',
	'texte_syndication' => 'Pódese recuperar automaticamente, e sempre que o sitio web o permita, 
  a súa lista de novidades. Para isto, ten que activar a afiliación.
  <blockquote><i>Algúns aloxadores desactivan esta funcionalidade;
  nese caso, non poderá empregar a afiliación de contido
  dende o seu web.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Artigos afiliados extraídos deste web',
	'titre_dernier_article_syndique' => 'Últimos artigos afiliados',
	'titre_page_sites_tous' => 'Os webs referidos',
	'titre_referencement_sites' => 'Referencia de webs e afiliación',
	'titre_site_numero' => 'WEB NÚMERO:',
	'titre_sites_proposes' => 'Os webs propostos',
	'titre_sites_references_rubrique' => 'Os webs referenciados neste tema',
	'titre_sites_syndiques' => 'Os webs afiliados',
	'titre_sites_tous' => 'Os webs referidos',
	'titre_syndication' => 'Subscrición de webs'
);

?>
